# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="$(dirname $NEW)/$(basename $NEW .new)"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}

preserve_perms etc/rc.d/rc.pcscd.new
config etc/sysconfig/pcscd.new

# Only way to create and use the correct uid and gid on the target system,
# is to use chroot:
chroot . <<EOR 2>/dev/null
# Add the '257' group if it doesn't exist already:
/usr/sbin/groupadd -g 257 pcscd 2> /dev/null

# Add the '257' user if it doesn't exist already:
/usr/sbin/useradd -c "PC/SC server account" -d /var/run/pcscd -M \
  -s "/bin/false" -g 257 -u 257 pcscd 2> /dev/null
EOR

# Update rc.local so that PC/SC daemon will be started on boot
if ! grep "rc.pcscd" etc/rc.d/rc.local 1>/dev/null 2>&1 ; then
  cat <<_EOM_ >> etc/rc.d/rc.local

if [ -x /etc/rc.d/rc.pcscd ]; then
  # Start PC/SC Smart Card daemon
  echo "Starting PC/SC daemon:    /etc/rc.d/rc.pcscd start"
  /etc/rc.d/rc.pcscd start
fi
_EOM_
fi

( cd usr/lib ; rm -rf libpcscspy.so )
( cd usr/lib ; ln -sf libpcscspy.so.0.0.0 libpcscspy.so )
( cd usr/lib ; rm -rf libpcscspy.so.0 )
( cd usr/lib ; ln -sf libpcscspy.so.0.0.0 libpcscspy.so.0 )
( cd usr/lib ; rm -rf libpcsclite.so.1 )
( cd usr/lib ; ln -sf libpcsclite.so.1.0.0 libpcsclite.so.1 )
( cd usr/lib ; rm -rf libpcsclite.so )
( cd usr/lib ; ln -sf libpcsclite.so.1.0.0 libpcsclite.so )
